==> grill-1.3.0.tar.gz: grill-1.3.0/setup.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""Setup script for frgal."""
import os

from setuptools import find_packages, setup


def long_description():
    """Return content of README file."""
    with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
        with open(os.path.join(os.path.dirname(__file__), 'ChangeLog.rst')) as changelog:
            return readme.read() + '\n\n' + changelog.read()


INSTALL_REQUIRES = open('requirements.txt').read().splitlines()
EXTRAS_REQUIRE = {'quality': ['bandit', 'isort', 'flake8', 'pydocstyle', 'mypy']}
VERSION = '1.3.0'


setup(name='grill',
      version=VERSION,
      description='gRPC interface logging library',
      long_description=long_description(),
      author='Vlastimil Zíma',
      author_email='vlastimil.zima@nic.cz',
      packages=find_packages(),
      include_package_data=True,
      python_requires='>=3.5',
      install_requires=INSTALL_REQUIRES,
      extras_require=EXTRAS_REQUIRE,
      classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Logging',
      ])

==> grill-1.3.1.tar.gz: grill-1.3.1/setup.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""Setup script for frgal."""
import os

from setuptools import find_packages, setup


def long_description():
    """Return content of README file."""
    with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
        with open(os.path.join(os.path.dirname(__file__), 'CHANGELOG.rst')) as changelog:
            return readme.read() + '\n\n' + changelog.read()


INSTALL_REQUIRES = open('requirements.txt').read().splitlines()
EXTRAS_REQUIRE = {'quality': ['bandit', 'isort', 'flake8', 'pydocstyle', 'mypy']}
VERSION = '1.3.1'


setup(name='grill',
      version=VERSION,
      description='gRPC interface logging library',
      long_description=long_description(),
      author='Vlastimil Zíma',
      author_email='vlastimil.zima@nic.cz',
      packages=find_packages(),
      include_package_data=True,
      python_requires='>=3.5',
      install_requires=INSTALL_REQUIRES,
      extras_require=EXTRAS_REQUIRE,
      classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Logging',
      ])
